import { isTokenValid } from "@api";
import { ApiToken } from "@api/types";
import userContext from "@ts/userContext";
import React, { useContext, useEffect } from "react";
import { useNavigate, useSearchParams } from "react-router-dom";

type AuthProps = {
    children: React.ReactNode,
}
export function AuthComponent({ children }: AuthProps) {
    const navigate = useNavigate();
    const user = useContext(userContext);

    async function checkIfCustomerLogged(token: ApiToken) {
        const isLogged: boolean = await isTokenValid(user.token);

        if (!isLogged) {
            user.setToken(null);
            user.setId(null);
            window.localStorage.removeItem("token");
            window.localStorage.removeItem("customerId");
        }
    }

    useEffect(() => {
        if (!user.token)
            navigate("/login", { replace: true });
        // navigate needs to be wrapped in a useEffect so that it gets executed after the component is mounted. Otherwise it doesn't redirect
        checkIfCustomerLogged(user.token);
    }, [user.token])

    // by default return the children, the effect will check if the user needs to be redirected
    return <>{children}</>;
}